==> subtitlecomposer_0.5.3.orig.tar.gz: subtitlecomposer-0.5.3/src/main/dialogs/clearerrorsdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#include "clearerrorsdialog.h"

#include <QtGui/QGridLayout>
#include <QtGui/QGroupBox>
#include <QtGui/QCheckBox>

#include <KLocale>
#include <KPushButton>

using namespace SubtitleComposer;

ClearErrorsDialog::ClearErrorsDialog( QWidget* parent ):
	ActionWithErrorTargetsDialog( i18n( "Clear Errors" ), parent )
{
	createErrorsGroupBox( i18nc( "@title:group", "Errors to Clear" ) );
	createErrorsButtons( true, translationMode() );

	createLineTargetsButtonGroup();
	createTextTargetsButtonGroup();
}

void ClearErrorsDialog::setTranslationMode( bool value )
{
	ActionWithErrorTargetsDialog::setTranslationMode( value );
	createErrorsButtons( true, value );
}


#include "clearerrorsdialog.moc"

==> subtitlecomposer_0.5.7.orig.tar.gz: subtitlecomposer-0.5.7/src/main/dialogs/clearerrorsdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#include "clearerrorsdialog.h"

#include <QtGui/QGridLayout>
#include <QtGui/QGroupBox>
#include <QtGui/QCheckBox>

#include <KLocale>
#include <KPushButton>

using namespace SubtitleComposer;

ClearErrorsDialog::ClearErrorsDialog(QWidget *parent) :
	ActionWithErrorTargetsDialog(i18n("Clear Errors"), parent)
{
	createErrorsGroupBox(i18nc("@title:group", "Errors to Clear"));
	createErrorsButtons(true, translationMode());

	createLineTargetsButtonGroup();
	createTextTargetsButtonGroup();
}

void
ClearErrorsDialog::setTranslationMode(bool value)
{
	ActionWithErrorTargetsDialog::setTranslationMode(value);
	createErrorsButtons(true, value);
}

#include "clearerrorsdialog.moc"
